diagnostic property
Diagnostic must be use only in the extension of the manager and not outside the package.
Implementation
@protected
List<T> get diagnostic => _diagnostics;
Diagnostic must be use only in the extension of the manager and not outside the package.
@protected
List<T> get diagnostic => _diagnostics;