dispose abstract method

Future<void> dispose()
inherited

This function must be call before the instance is created an usually have close streams or dispose clients

Implementation

Future<void> dispose();