init abstract method
This function must be call at the begining of the initilalization.
Usually set the sdk with the needed options
Implementation
Future<void> init();
This function must be call at the begining of the initilalization.
Usually set the sdk with the needed options
Future<void> init();