Interface for manage differents diagnostics tool as Firebase/Flutter_Sentry/Cloudwatch.
Provide a common interface for manage the different flutter diagnostic SDK.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → DiagnosticOption
-
Provide the multiple options for initialize or manage the diagnostic sdk
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureException(
{required covariant DiagnosticExpection exception}) → FutureOr< void> -
Send an exception with the custom informate implement.
Should check for the class runtime if filter is required.
inherited
-
dispose(
) → Future< void> -
This function must be call before the instance is created an usually have close streams or dispose clients
inherited
-
init(
) → Future< void> -
This function must be call at the begining of the initilalization.
inherited
- Return a custom Route observer instanciate for your Flutter app.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendAnalyticEvent(
{required covariant DiagnosticAnalyticEvent event}) → FutureOr< void> -
Send an analyticEvent with the custom informate implement.
Should filter what level is not required.
inherited
-
sendLogEvent(
{required covariant DiagnosticLogsEvent event}) → FutureOr< void> -
Send an log with the custom informate implement.
Should filter what level is not required.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited