captureException abstract method
Send an exception with the custom informate implement. Should check for the class runtime if filter is required.
A DiagnosticExpection extension can be create if the sdk need or have
custom information
Implementation
FutureOr<void> captureException({
required covariant DiagnosticExpection exception,
});