dispose abstract method
This function must be call before the instance is created an usually have close streams or dispose clients
Implementation
Future<void> dispose();
This function must be call before the instance is created an usually have close streams or dispose clients
Future<void> dispose();