options property
DiagnosticOption
options
finalinherited
Provide the multiple options for initialize or manage the diagnostic sdk
Contains also the bool options for send or not exception, event or logs.
Implementation
final DiagnosticOption options;